==> v11.1.2.zip: brewman/overlord/src/app/app-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { LoginComponent } from './auth/login/login.component';
import { LogoutComponent } from './auth/logout/logout.component';
import { HomeComponent } from './home/home.component';

const appRoutes: Routes = [
  {
    path: 'accounts',
    loadChildren: () => import('./account/account.module').then((mod) => mod.AccountModule),
  },
  {
    path: 'attendance',
    loadChildren: () =>
      import('./attendance/attendance.module').then((mod) => mod.AttendanceModule),
  },
  {
    path: 'balance-sheet',
    loadChildren: () =>
      import('./balance-sheet/balance-sheet.module').then((mod) => mod.BalanceSheetModule),
  },
  {
    path: 'batch-integrity-report',
    loadChildren: () =>
      import('./batch-integrity-report/batch-integrity-report.module').then(
        (mod) => mod.BatchIntegrityReportModule,
      ),
  },
  {
    path: 'cash-flow',
    loadChildren: () => import('./cash-flow/cash-flow.module').then((mod) => mod.CashFlowModule),
  },
  {
    path: 'clients',
    loadChildren: () => import('./client/client.module').then((mod) => mod.ClientModule),
  },
  {
    path: 'closing-stock',
    loadChildren: () =>
      import('./closing-stock/closing-stock.module').then((mod) => mod.ClosingStockModule),
  },
  {
    path: 'cost-centres',
    loadChildren: () =>
      import('./cost-centre/cost-centre.module').then((mod) => mod.CostCentreModule),
  },
  {
    path: 'daybook',
    loadChildren: () => import('./daybook/daybook.module').then((mod) => mod.DaybookModule),
  },
  {
    path: 'employees',
    loadChildren: () => import('./employee/employee.module').then((mod) => mod.EmployeeModule),
  },
  {
    path: 'employee-attendance',
    loadChildren: () =>
      import('./employee-attendance/employee-attendance.module').then(
        (mod) => mod.EmployeeAttendanceModule,
      ),
  },
  {
    path: 'employee-benefits',
    loadChildren: () =>
      import('./employee-benefits/employee-benefits.module').then(
        (mod) => mod.EmployeeBenefitsModule,
      ),
  },
  {
    path: 'employee-functions',
    loadChildren: () =>
      import('./employee-functions/employee-functions.module').then(
        (mod) => mod.EmployeeFunctionsModule,
      ),
  },
  {
    path: 'rate-contracts',
    loadChildren: () =>
      import('./rate-contract/rate-contract.module').then((mod) => mod.RateContractModule),
  },
  {
    path: 'recipes',
    loadChildren: () => import('./recipe/recipe.module').then((mod) => mod.RecipeModule),
  },
  {
    path: 'recipe-templates',
    loadChildren: () =>
      import('./recipe-template/recipe-template.module').then((mod) => mod.RecipeTemplateModule),
  },
  {
    path: 'roles',
    loadChildren: () => import('./role/role.module').then((mod) => mod.RoleModule),
  },
  {
    path: 'incentive',
    loadChildren: () => import('./incentive/incentive.module').then((mod) => mod.IncentiveModule),
  },
  {
    path: 'issue',
    loadChildren: () => import('./issue/issue.module').then((mod) => mod.IssueModule),
  },
  {
    path: 'journal',
    loadChildren: () => import('./journal/journal.module').then((mod) => mod.JournalModule),
  },
  {
    path: 'ledger',
    loadChildren: () => import('./ledger/ledger.module').then((mod) => mod.LedgerModule),
  },
  {
    path: 'net-transactions',
    loadChildren: () =>
      import('./net-transactions/net-transactions.module').then((mod) => mod.NetTransactionsModule),
  },
  {
    path: 'non-contract-purchase',
    loadChildren: () =>
      import('./non-contact-purchase/non-contract-purchase.module').then(
        (mod) => mod.NonContractPurchaseModule,
      ),
  },
  {
    path: 'payment',
    loadChildren: () => import('./payment/payment.module').then((mod) => mod.PaymentModule),
  },
  {
    path: 'periods',
    loadChildren: () => import('./period/period.module').then((mod) => mod.PeriodModule),
  },
  {
    path: 'products',
    loadChildren: () => import('./product/product.module').then((mod) => mod.ProductModule),
  },
  {
    path: 'product-groups',
    loadChildren: () =>
      import('./product-group/product-group.module').then((mod) => mod.ProductGroupModule),
  },
  {
    path: 'product-ledger',
    loadChildren: () =>
      import('./product-ledger/product-ledger.module').then((mod) => mod.ProductLedgerModule),
  },
  {
    path: 'profit-loss',
    loadChildren: () =>
      import('./profit-loss/profit-loss.module').then((mod) => mod.ProfitLossModule),
  },
  {
    path: 'purchase',
    loadChildren: () => import('./purchase/purchase.module').then((mod) => mod.PurchaseModule),
  },
  {
    path: 'purchase-entries',
    loadChildren: () =>
      import('./purchase-entries/purchase-entries.module').then((mod) => mod.PurchaseEntriesModule),
  },
  {
    path: 'purchases',
    loadChildren: () => import('./purchases/purchases.module').then((mod) => mod.PurchasesModule),
  },
  {
    path: 'raw-material-cost',
    loadChildren: () =>
      import('./raw-material-cost/raw-material-cost.module').then(
        (mod) => mod.RawMaterialCostModule,
      ),
  },
  {
    path: 'receipt',
    loadChildren: () => import('./receipt/receipt.module').then((mod) => mod.ReceiptModule),
  },
  {
    path: 'purchase-return',
    loadChildren: () =>
      import('./purchase-return/purchase-return.module').then((mod) => mod.PurchaseReturnModule),
  },
  {
    path: 'settings',
    loadChildren: () => import('./settings/settings.module').then((mod) => mod.SettingsModule),
  },
  {
    path: 'stock-movement',
    loadChildren: () =>
      import('./stock-movement/stock-movement.module').then((mod) => mod.StockMovementModule),
  },
  {
    path: 'trial-balance',
    loadChildren: () =>
      import('./trial-balance/trial-balance.module').then((mod) => mod.TrialBalanceModule),
  },
  {
    path: 'entries',
    loadChildren: () => import('./entries/entries.module').then((mod) => mod.EntriesModule),
  },
  {
    path: 'users',
    loadChildren: () => import('./user/user.module').then((mod) => mod.UserModule),
  },
  { path: 'login', component: LoginComponent },
  { path: 'logout', component: LogoutComponent },
  { path: '', component: HomeComponent },
];

@NgModule({
  imports: [
    CommonModule,
    RouterModule.forRoot(appRoutes, {
      onSameUrlNavigation: 'reload',
    }),
  ],
  exports: [RouterModule],
  declarations: [],
})
export class AppRoutingModule {}

==> v11.1.5.zip: brewman/overlord/src/app/app-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { LoginComponent } from './auth/login/login.component';
import { LogoutComponent } from './auth/logout/logout.component';
import { HomeComponent } from './home/home.component';

const appRoutes: Routes = [
  {
    path: 'accounts',
    loadChildren: () => import('./account/account.module').then((mod) => mod.AccountModule),
  },
  {
    path: 'attendance',
    loadChildren: () => import('./attendance/attendance.module').then((mod) => mod.AttendanceModule),
  },
  {
    path: 'balance-sheet',
    loadChildren: () => import('./balance-sheet/balance-sheet.module').then((mod) => mod.BalanceSheetModule),
  },
  {
    path: 'batch-integrity-report',
    loadChildren: () =>
      import('./batch-integrity-report/batch-integrity-report.module').then((mod) => mod.BatchIntegrityReportModule),
  },
  {
    path: 'cash-flow',
    loadChildren: () => import('./cash-flow/cash-flow.module').then((mod) => mod.CashFlowModule),
  },
  {
    path: 'clients',
    loadChildren: () => import('./client/client.module').then((mod) => mod.ClientModule),
  },
  {
    path: 'closing-stock',
    loadChildren: () => import('./closing-stock/closing-stock.module').then((mod) => mod.ClosingStockModule),
  },
  {
    path: 'cost-centres',
    loadChildren: () => import('./cost-centre/cost-centre.module').then((mod) => mod.CostCentreModule),
  },
  {
    path: 'daybook',
    loadChildren: () => import('./daybook/daybook.module').then((mod) => mod.DaybookModule),
  },
  {
    path: 'employees',
    loadChildren: () => import('./employee/employee.module').then((mod) => mod.EmployeeModule),
  },
  {
    path: 'employee-attendance',
    loadChildren: () =>
      import('./employee-attendance/employee-attendance.module').then((mod) => mod.EmployeeAttendanceModule),
  },
  {
    path: 'employee-benefits',
    loadChildren: () =>
      import('./employee-benefits/employee-benefits.module').then((mod) => mod.EmployeeBenefitsModule),
  },
  {
    path: 'employee-functions',
    loadChildren: () =>
      import('./employee-functions/employee-functions.module').then((mod) => mod.EmployeeFunctionsModule),
  },
  {
    path: 'rate-contracts',
    loadChildren: () => import('./rate-contract/rate-contract.module').then((mod) => mod.RateContractModule),
  },
  {
    path: 'recipes',
    loadChildren: () => import('./recipe/recipe.module').then((mod) => mod.RecipeModule),
  },
  {
    path: 'recipe-templates',
    loadChildren: () => import('./recipe-template/recipe-template.module').then((mod) => mod.RecipeTemplateModule),
  },
  {
    path: 'roles',
    loadChildren: () => import('./role/role.module').then((mod) => mod.RoleModule),
  },
  {
    path: 'incentive',
    loadChildren: () => import('./incentive/incentive.module').then((mod) => mod.IncentiveModule),
  },
  {
    path: 'issue',
    loadChildren: () => import('./issue/issue.module').then((mod) => mod.IssueModule),
  },
  {
    path: 'journal',
    loadChildren: () => import('./journal/journal.module').then((mod) => mod.JournalModule),
  },
  {
    path: 'ledger',
    loadChildren: () => import('./ledger/ledger.module').then((mod) => mod.LedgerModule),
  },
  {
    path: 'net-transactions',
    loadChildren: () => import('./net-transactions/net-transactions.module').then((mod) => mod.NetTransactionsModule),
  },
  {
    path: 'non-contract-purchase',
    loadChildren: () =>
      import('./non-contact-purchase/non-contract-purchase.module').then((mod) => mod.NonContractPurchaseModule),
  },
  {
    path: 'payment',
    loadChildren: () => import('./payment/payment.module').then((mod) => mod.PaymentModule),
  },
  {
    path: 'periods',
    loadChildren: () => import('./period/period.module').then((mod) => mod.PeriodModule),
  },
  {
    path: 'products',
    loadChildren: () => import('./product/product.module').then((mod) => mod.ProductModule),
  },
  {
    path: 'product-groups',
    loadChildren: () => import('./product-group/product-group.module').then((mod) => mod.ProductGroupModule),
  },
  {
    path: 'product-ledger',
    loadChildren: () => import('./product-ledger/product-ledger.module').then((mod) => mod.ProductLedgerModule),
  },
  {
    path: 'profit-loss',
    loadChildren: () => import('./profit-loss/profit-loss.module').then((mod) => mod.ProfitLossModule),
  },
  {
    path: 'purchase',
    loadChildren: () => import('./purchase/purchase.module').then((mod) => mod.PurchaseModule),
  },
  {
    path: 'purchase-entries',
    loadChildren: () => import('./purchase-entries/purchase-entries.module').then((mod) => mod.PurchaseEntriesModule),
  },
  {
    path: 'purchases',
    loadChildren: () => import('./purchases/purchases.module').then((mod) => mod.PurchasesModule),
  },
  {
    path: 'raw-material-cost',
    loadChildren: () => import('./raw-material-cost/raw-material-cost.module').then((mod) => mod.RawMaterialCostModule),
  },
  {
    path: 'receipt',
    loadChildren: () => import('./receipt/receipt.module').then((mod) => mod.ReceiptModule),
  },
  {
    path: 'purchase-return',
    loadChildren: () => import('./purchase-return/purchase-return.module').then((mod) => mod.PurchaseReturnModule),
  },
  {
    path: 'settings',
    loadChildren: () => import('./settings/settings.module').then((mod) => mod.SettingsModule),
  },
  {
    path: 'stock-movement',
    loadChildren: () => import('./stock-movement/stock-movement.module').then((mod) => mod.StockMovementModule),
  },
  {
    path: 'trial-balance',
    loadChildren: () => import('./trial-balance/trial-balance.module').then((mod) => mod.TrialBalanceModule),
  },
  {
    path: 'entries',
    loadChildren: () => import('./entries/entries.module').then((mod) => mod.EntriesModule),
  },
  {
    path: 'users',
    loadChildren: () => import('./user/user.module').then((mod) => mod.UserModule),
  },
  { path: 'login', component: LoginComponent },
  { path: 'logout', component: LogoutComponent },
  { path: '', component: HomeComponent },
];

@NgModule({
  imports: [
    CommonModule,
    RouterModule.forRoot(appRoutes, {
      onSameUrlNavigation: 'reload',
    }),
  ],
  exports: [RouterModule],
  declarations: [],
})
export class AppRoutingModule {}
